@@ -19,6 +19,12 @@ set clk48 [list]
 
 for {set i 0} {$i < $nfacs } {incr i} {
     set facname [ gtkwave::getFacName $i ]
+
+#    set facdir  [ gtkwave::getFacDir $i ]
+#    set facvtype  [ gtkwave::getFacVtype $i ]
+#    set facdtype  [ gtkwave::getFacDtype $i ]
+#    puts "facname: $facname, facdir: $facdir, facvtype: $facvtype, facdtype: $facdtype"
+
     set indx [ string first "\[1:48\]" $facname  ]
     if {$indx == -1} {
     set indx [ string first clk $facname  ]
@@ -42,4 +48,4 @@ gtkwave::setMarker 128
 gtkwave::setNamedMarker A 400 "Example Named Marker"
 
 gtkwave::/File/Print_To_File PS {Letter (8.5" x 11")} Full $dumpname.ps
-gtkwave::/File/Quit/Yes,_Quit
+gtkwave::/File/Quit
